@@ -36,7 +36,7 @@ class Learner():
         stats = load_model(self.model, p, show=show)
         if not update_best:
             return
-        # self.eval()
+        self.eval()
         self.logger.df_best = pd.DataFrame.from_dict(stats)
         k = 4+len(self.metrics)
         self.logger.best = self.logger.df_best.iloc[0,k]
@@ -125,7 +125,8 @@ class Learner():
         # Reset optimizer status
 
     def eval(self):
-        if not self.data.dl2: return
+        if not self.data.dl2:
+            return
         self.model.eval()
         with torch.no_grad(): 
             if not self('begin_validate'): self.all_batches(self.data.dl2)
