@@ -209,7 +209,7 @@ class SignalNet(nn.Module):
             szs += [(n1,sz)]
         net += [nn.AdaptiveMaxPool1d(1)]
         net += [Flatten()]
-        net += [Linear(1*n1, 1024, p=p)]
+        net += [Linear(n1, 1024, p=p)]
         net += [LinearFinal(1024, c, p=None)]
         self.net = nn.Sequential(*net)
         if show: model_stats(self, bottle=bottle, szs=szs, show_szs=True)
