@@ -224,12 +224,22 @@ class Results_Clsf():
     def get_wrong(self, actual=None, n=8):
         idx = np.where(self.actuals!=self.preds)[0]
         if actual is not None:
-            idx = [i for i in idx if self.actual[i]==actual]
+            idx = [i for i in idx if self.actuals[i]==actual]
+        return idx[:n]
+    def get_most_confident(self, actual=None, pred=None, n=8):
+        idx = np.argsort(np.absolute(self.probs-.5))[::-1]
+        if actual is not None:
+            idx = [e for e in idx if self.actuals[e]==actual]
+        if pred is not None:
+            idx = [e for e in idx if self.preds[e]==pred]
+        return idx[:n]
+    def get_least_confident(self, actual=None, pred=None, n=8):
+        idx = np.argsort(np.absolute(self.probs-.5))
+        if actual is not None:
+            idx = [e for e in idx if self.actuals[e]==actual]
+        if pred is not None:
+            idx = [e for e in idx if self.preds[e]==pred]
         return idx[:n]
-    def get_most_confident(self, n=8):
-        return np.argsort(np.absolute(self.probs-.5))[::-1][:n]
-    def get_least_confident(self, n=8):
-        return np.argsort(np.absolute(self.probs-.5))[:n]
 
 class Results_Clsf_Tabular(Results_Clsf):
     def __init__(self, data, df):
