@@ -8,9 +8,9 @@ from dl2050nn.results import Results_Clsf
 from dl2050nn.log import key_metric
 
 class Runner:
-    def __init__(self, path, data=None, get_learner=None, model=None, nruns=10, eps=10, name='Runner', desc='', pre=None):
+    def __init__(self, path, model=None, data=None, get_learner=None, nruns=10, eps=10, name='Runner', desc='', pre=None):
+        self.path,self.model = path,model
         self.get_learner,self.data = get_learner,data
-        self.model = model
         self.nruns,self.eps,self.name,self.desc,self.pre = nruns,eps,name,desc,pre
         if not Path(f'{path}/runners').exists(): Path(f'{path}/runners').mkdir()
         self.fname = f'{path}/runners/{name}'
